@@ -1,26 +1,10 @@
-/***************************************************************************
-
-                   create a KEduVocDocument from a Vokabeln file
-
-    -----------------------------------------------------------------------
-
-    begin        : Wed Jun 15 19:32:00 PDT 2005
-
-    copyright    : (C) 2005, 2007 Peter Hedlund <peter.hedlund@kdemail.net>
-                   (C) 2007 Frederik Gladhorn <frederik.gladhorn@kdemail.net>
-
-    -----------------------------------------------------------------------
-
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+ * create a KEduVocDocument from a Vokabeln file
+ *
+ * SPDX-FileCopyrightText: 2005, 2007 Peter Hedlund <peter.hedlund@kdemail.net>
+ * SPDX-FileCopyrightText: 2007 Frederik Gladhorn <frederik.gladhorn@kdemail.net>
+ * SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "keduvocvokabelnreader.h"
 
